
#  HistoFile.py
#  M.Lampton August 2017
#  Plots a histogram of the ray error counts; always use 400 bins

import matplotlib.pyplot as plt
import numpy as np

ZEROBIN = 200   # all plots span -200 to +200 ppm
xlist = list()
ylist = list()
xmin = -200.0
xmax = 200.0
fname = '120fid-L13ortho2-100ppm.txt'
with open(fname, 'r') as file:
    for row in file:
        a, b = row.split()
        x = int(a) - ZEROBIN
        y = int(b)
        if x>xmin and x<xmax:
            xlist.append(x)
            ylist.append(y)
listlen = len(xlist)  # 199 items

sumx = 0.
sumx2 = 0.
sumy = 0.
listlen = len(xlist)  # new shorter list here.
for i in range(0, listlen):
    sumx += ylist[i]*xlist[i]
    sumx2 += ylist[i]*xlist[i]**2
    sumy += ylist[i]
print 'sumx, sumx2, sumy, listlen :', sumx, sumx2, sumy, listlen
mean = sumx/sumy
var = sumx2/sumy - mean**2
rms = np.sqrt(var)
rmsstr = '1D rms = {:.2f} ppm'.format(rms) 
npoints = 'Npoints = '+str(int(sumy))
print 'mean, var, rms = ', mean, var, rms

fig = plt.figure(figsize = (5.,5.))  # inches
ax = fig.add_axes([0.2, 0.2, 0.7, 0.7])  
ax.set_xlim(xmin, xmax)
ax.plot(xlist, ylist)                   # draw a connected curve
for row in range(1,len(xlist)):         # draw vertical bars 
    ax.plot([xlist[row], xlist[row]], [0, ylist[row]], color='b', linewidth=2)
ax.set_xlabel('1D rms error, parts per million')
ax.set_ylabel('samples per bin')
ax.text(0.02, 0.95, npoints,  transform=ax.transAxes, fontsize=10)  # box fraction coordinates
ax.text(0.55, 0.95, rmsstr, transform=ax.transAxes, fontsize=10)  # box fraction coordinates
plt.title(fname) 
fig.savefig(fname+'-histo.eps', format='eps', dpi=1200)
plt.show()

